| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ResourceExplorer2.ListSupportedResourceTypes
Description
Retrieves a list of all resource types currently supported by Amazon Web Services Resource Explorer.
This operation returns paginated results.
Synopsis
- data ListSupportedResourceTypes = ListSupportedResourceTypes' {}
- newListSupportedResourceTypes :: ListSupportedResourceTypes
- listSupportedResourceTypes_maxResults :: Lens' ListSupportedResourceTypes (Maybe Natural)
- listSupportedResourceTypes_nextToken :: Lens' ListSupportedResourceTypes (Maybe Text)
- data ListSupportedResourceTypesResponse = ListSupportedResourceTypesResponse' {}
- newListSupportedResourceTypesResponse :: Int -> ListSupportedResourceTypesResponse
- listSupportedResourceTypesResponse_nextToken :: Lens' ListSupportedResourceTypesResponse (Maybe Text)
- listSupportedResourceTypesResponse_resourceTypes :: Lens' ListSupportedResourceTypesResponse (Maybe [SupportedResourceType])
- listSupportedResourceTypesResponse_httpStatus :: Lens' ListSupportedResourceTypesResponse Int
Creating a Request
data ListSupportedResourceTypes Source #
See: newListSupportedResourceTypes smart constructor.
Constructors
| ListSupportedResourceTypes' | |
Fields
| |
Instances
newListSupportedResourceTypes :: ListSupportedResourceTypes Source #
Create a value of ListSupportedResourceTypes with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:maxResults:ListSupportedResourceTypes', listSupportedResourceTypes_maxResults - The maximum number of results that you want included on each page of the
response. If you do not include this parameter, it defaults to a value
appropriate to the operation. If additional items exist beyond those
included in the current response, the NextToken response element is
present and has a value (is not null). Include that value as the
NextToken request parameter in the next call to the operation to get
the next part of the results.
An API operation can return fewer results than the maximum even when
there are more results available. You should check NextToken after
every operation to ensure that you receive all of the results.
ListSupportedResourceTypes, listSupportedResourceTypes_nextToken - The parameter for receiving additional results if you receive a
NextToken response in a previous request. A NextToken response
indicates that more output is available. Set this parameter to the value
of the previous call's NextToken response to indicate where the
output should continue from.
Request Lenses
listSupportedResourceTypes_maxResults :: Lens' ListSupportedResourceTypes (Maybe Natural) Source #
The maximum number of results that you want included on each page of the
response. If you do not include this parameter, it defaults to a value
appropriate to the operation. If additional items exist beyond those
included in the current response, the NextToken response element is
present and has a value (is not null). Include that value as the
NextToken request parameter in the next call to the operation to get
the next part of the results.
An API operation can return fewer results than the maximum even when
there are more results available. You should check NextToken after
every operation to ensure that you receive all of the results.
listSupportedResourceTypes_nextToken :: Lens' ListSupportedResourceTypes (Maybe Text) Source #
The parameter for receiving additional results if you receive a
NextToken response in a previous request. A NextToken response
indicates that more output is available. Set this parameter to the value
of the previous call's NextToken response to indicate where the
output should continue from.
Destructuring the Response
data ListSupportedResourceTypesResponse Source #
See: newListSupportedResourceTypesResponse smart constructor.
Constructors
| ListSupportedResourceTypesResponse' | |
Fields
| |
Instances
newListSupportedResourceTypesResponse Source #
Arguments
| :: Int | |
| -> ListSupportedResourceTypesResponse |
Create a value of ListSupportedResourceTypesResponse with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
ListSupportedResourceTypes, listSupportedResourceTypesResponse_nextToken - If present, indicates that more output is available than is included in
the current response. Use this value in the NextToken request
parameter in a subsequent call to the operation to get the next part of
the output. You should repeat this until the NextToken response
element comes back as null.
$sel:resourceTypes:ListSupportedResourceTypesResponse', listSupportedResourceTypesResponse_resourceTypes - The list of resource types supported by Resource Explorer.
$sel:httpStatus:ListSupportedResourceTypesResponse', listSupportedResourceTypesResponse_httpStatus - The response's http status code.
Response Lenses
listSupportedResourceTypesResponse_nextToken :: Lens' ListSupportedResourceTypesResponse (Maybe Text) Source #
If present, indicates that more output is available than is included in
the current response. Use this value in the NextToken request
parameter in a subsequent call to the operation to get the next part of
the output. You should repeat this until the NextToken response
element comes back as null.
listSupportedResourceTypesResponse_resourceTypes :: Lens' ListSupportedResourceTypesResponse (Maybe [SupportedResourceType]) Source #
The list of resource types supported by Resource Explorer.
listSupportedResourceTypesResponse_httpStatus :: Lens' ListSupportedResourceTypesResponse Int Source #
The response's http status code.