| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ResourceExplorer2.Types.SearchFilter
Description
Synopsis
Documentation
data SearchFilter Source #
A search filter defines which resources can be part of a search query result set.
See: newSearchFilter smart constructor.
Constructors
| SearchFilter' | |
Fields
| |
Instances
Arguments
| :: Text | |
| -> SearchFilter |
Create a value of SearchFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:filterString:SearchFilter', searchFilter_filterString - The string that contains the search keywords, prefixes, and operators to
control the results that can be returned by a Search operation. For more
details, see
Search query syntax.
searchFilter_filterString :: Lens' SearchFilter Text Source #
The string that contains the search keywords, prefixes, and operators to control the results that can be returned by a Search operation. For more details, see Search query syntax.